@@ -19,7 +19,7 @@ dt_footnotes_init <- function(data) {
     locnum = numeric(0),
     rownum = integer(0),
     colnum = integer(0),
-    footnotes = character(0)
+    footnotes = list(character(0))
   ) %>%
     dt_footnotes_set(footnotes = ., data = data)
 }
@@ -42,7 +42,7 @@ dt_footnotes_add <- function(data,
         locnum = locnum,
         rownum = rownum,
         colnum = NA_integer_,
-        footnotes = footnotes
+        footnotes = list(footnotes)
       )
     ) %>%
     dt_footnotes_set(footnotes = ., data = data)
