@@ -192,8 +192,8 @@ pct <- function(x) {
 #' The `cells_title()` function is used to target the table title or subtitle
 #' when applying a footnote with [tab_footnote()] or adding custom style with
 #' [tab_style()]. The function is expressly used in each of those functions'
-#' `locations` argument. The 'title' location is generated by the [tab_header()]
-#' function.
+#' `locations` argument. The header location where the title and optionally the
+#' subtitle reside is generated by the [tab_header()] function.
 #'
 #' @section Overview of Location Helper Functions:
 #' Location helper functions can be used to target cells with virtually any
@@ -234,8 +234,9 @@ pct <- function(x) {
 #' can be targeted by enclosing several `cells_*()` helper functions in a
 #' `list()` (e.g., `list(cells_body(), cells_grand_summary())`).
 #'
-#' @param groups We can either specify `"title"` or `"subtitle"` to target the
-#'   title element or the subtitle element.
+#' @param groups We can either specify `"title"`, `"subtitle"`, or both (the
+#'   default) in a vector to target the title element, the subtitle element, or
+#'   both elements.
 #'
 #' @return A list object of classes `cells_title` and `location_cells`.
 #'
@@ -271,6 +272,20 @@ pct <- function(x) {
 #' @export
 cells_title <- function(groups = c("title", "subtitle")) {
 
+  # Stop function if the `groups` input is invalid
+  if (
+    is.null(groups) ||
+    !is.character(groups) ||
+    length(groups) < 1 ||
+    !all(groups %in% c("title", "subtitle")) ||
+    any(duplicated(groups))
+  ) {
+    stop(
+      "The input to `groups` must be either `\"title\"`, `\"subtitle\"`, or both.",
+      call. = FALSE
+    )
+  }
+
   # Capture expression for the `groups` argument
   groups_expr <- rlang::enquo(groups)
 
