@@ -3,9 +3,15 @@
 #' @noRd
 footnote_mark_to_html <- function(mark) {
 
-  as.character(
-    htmltools::tagList(htmltools::tags$sup(class = "gt_footnote_marks", mark))
-  )
+  # Generate the CSS classes needed on the basis of whether the
+  # mark is one or more asterisk characters or anything else
+  if (!grepl("^[\\*]+?$", mark)) {
+    sup_class <- "gt_footnote_marks"
+  } else {
+    sup_class <- "gt_footnote_marks gt_asterisk"
+  }
+
+  as.character(htmltools::tags$sup(class = sup_class, mark))
 }
 
 styles_to_html <- function(styles) {
@@ -54,14 +60,7 @@ add_css_styles <- function(data) {
 
   styles_tbl <- dt_styles_get(data = data)
 
-  if (nrow(styles_tbl) > 0) {
-    styles_tbl <-
-      dplyr::mutate(
-        styles_tbl,
-        html_style = vapply(
-          styles, function(x) styles_to_html(x), character(1))
-      )
-  }
+  styles_tbl$html_style <- vapply(styles_tbl$styles, styles_to_html, character(1))
 
   dt_styles_set(data = data, styles = styles_tbl)
 }
@@ -208,21 +207,10 @@ create_heading_component_h <- function(data) {
   heading <- dt_heading_get(data = data)
   footnotes_tbl <- dt_footnotes_get(data = data)
   styles_tbl <- dt_styles_get(data = data)
-  stub_components <- dt_stub_components(data = data)
   subtitle_defined <- dt_heading_has_subtitle(data = data)
 
-  # Obtain the number of visible columns in the built table
-  n_data_cols <- length(dt_boxhead_get_vars_default(data = data))
-
-  # Determine whether the stub is available
-  stub_available <- dt_stub_components_has_rowname(stub_components)
-
-  # If a stub is present then the effective number of columns increases by 1
-  if (stub_available) {
-    n_cols <- n_data_cols + 1
-  } else {
-    n_cols <- n_data_cols
-  }
+  # Get effective number of columns
+  n_cols_total <- get_effective_number_of_columns(data = data)
 
   # Get the footnote marks for the title
   if ("title" %in% footnotes_tbl$locname) {
@@ -299,7 +287,7 @@ create_heading_component_h <- function(data) {
   title_row <-
     htmltools::tags$tr(
       htmltools::tags$th(
-        colspan = n_cols,
+        colspan = n_cols_total,
         class = paste(title_classes, collapse = " "),
         style = title_styles,
         htmltools::HTML(
@@ -313,7 +301,7 @@ create_heading_component_h <- function(data) {
     subtitle_row <-
       htmltools::tags$tr(
         htmltools::tags$th(
-          colspan = n_cols,
+          colspan = n_cols_total,
           class = paste(subtitle_classes, collapse = " "),
           style = subtitle_styles,
           htmltools::HTML(
@@ -338,20 +326,6 @@ create_heading_component_h <- function(data) {
 #' @noRd
 create_columns_component_h <- function(data) {
 
-  boxh <- dt_boxhead_get(data = data)
-  stubh <- dt_stubhead_get(data = data)
-  body <- dt_body_get(data = data)
-  styles_tbl <- dt_styles_get(data = data)
-  stub_available <- dt_stub_df_exists(data = data)
-  spanners_present <- dt_spanners_exists(data = data)
-
-  # Get the column alignments for all visible columns
-  col_alignment <- dplyr::pull(subset(boxh, type == "default"), column_align)
-
-  # Get the column headings
-  headings_vars <- dplyr::pull(subset(boxh, type == "default"), var)
-  headings_labels <- dt_boxhead_get_vars_labels_default(data = data)
-
   # Should the column labels be hidden?
   column_labels_hidden <-
     dt_options_get_value(
@@ -363,6 +337,22 @@ create_columns_component_h <- function(data) {
     return("")
   }
 
+  stubh <- dt_stubhead_get(data = data)
+  styles_tbl <- dt_styles_get(data = data)
+
+  # Get vector representation of stub layout
+  stub_layout <- get_stub_layout(data = data)
+
+  # Determine if there are any spanners present
+  spanners_present <- dt_spanners_exists(data = data)
+
+  # Get the column alignments and also the alignment class names
+  col_alignment <- dt_boxhead_get_vars_align_default(data = data)
+
+  # Get the column headings
+  headings_vars <- dt_boxhead_get_vars_default(data = data)
+  headings_labels <- dt_boxhead_get_vars_labels_default(data = data)
+
   # Get the style attrs for the stubhead label
   stubhead_style_attrs <- subset(styles_tbl, locname == "stubhead")
 
@@ -372,14 +362,14 @@ create_columns_component_h <- function(data) {
   # Get the style attrs for the spanner column headings
   column_style_attrs <- subset(styles_tbl, locname == "columns_columns")
 
-  # If `stub_available` == TRUE, then replace with a set stubhead
+  # If columns are present in the stub, then replace with a set stubhead
   # label or nothing
-  if (isTRUE(stub_available) && length(stubh$label) > 0) {
+  if (length(stub_layout) > 0 && length(stubh$label) > 0) {
 
     headings_labels <- prepend_vec(headings_labels, stubh$label)
     headings_vars <- prepend_vec(headings_vars, "::stub")
 
-  } else if (isTRUE(stub_available)) {
+  } else if (length(stub_layout) > 0) {
 
     headings_labels <- prepend_vec(headings_labels, "")
     headings_vars <- prepend_vec(headings_vars, "::stub")
@@ -392,7 +382,7 @@ create_columns_component_h <- function(data) {
   if (!spanners_present) {
 
     # Create the cell for the stubhead label
-    if (isTRUE(stub_available)) {
+    if (length(stub_layout) > 0) {
 
       stubhead_style <-
         if (nrow(stubhead_style_attrs) > 0) {
@@ -408,7 +398,7 @@ create_columns_component_h <- function(data) {
               paste0("gt_", stubhead_label_alignment)),
             collapse = " "),
           rowspan = 1,
-          colspan = 1,
+          colspan = length(stub_layout),
           style = stubhead_style,
           htmltools::HTML(headings_labels[1])
         )
@@ -417,7 +407,7 @@ create_columns_component_h <- function(data) {
       headings_labels <- headings_labels[-1]
     }
 
-    for (i in seq(headings_vars)) {
+    for (i in seq_along(headings_vars)) {
 
       styles_column <- subset(column_style_attrs, colnum == i)
 
@@ -458,7 +448,7 @@ create_columns_component_h <- function(data) {
     second_set <- list()
 
     # Create the cell for the stubhead label
-    if (stub_available) {
+    if (length(stub_layout) > 0) {
 
       stubhead_style <-
         if (nrow(stubhead_style_attrs) > 0) {
@@ -470,14 +460,11 @@ create_columns_component_h <- function(data) {
       first_set[[length(first_set) + 1]] <-
         htmltools::tags$th(
           class = paste(
-            c(
-              "gt_col_heading",
-              "gt_columns_bottom_border",
-              paste0("gt_", stubhead_label_alignment)
-            ),
+            c("gt_col_heading", "gt_columns_bottom_border",
+              paste0("gt_", stubhead_label_alignment)),
             collapse = " "),
           rowspan = 2,
-          colspan = 1,
+          colspan = length(stub_layout),
           style = stubhead_style,
           htmltools::HTML(headings_labels[1])
         )
@@ -503,7 +490,7 @@ create_columns_component_h <- function(data) {
       0
     )
 
-    for (i in seq(headings_vars)) {
+    for (i in seq_along(headings_vars)) {
 
       if (is.na(spanner_ids[i])) {
 
@@ -585,10 +572,8 @@ create_columns_component_h <- function(data) {
     solo_headings <- headings_vars[is.na(spanner_ids)]
     remaining_headings <- headings_vars[!(headings_vars %in% solo_headings)]
 
-    remaining_headings_indices <- which(remaining_headings %in% headings_vars)
-
     remaining_headings_labels <-
-      boxh %>%
+      dt_boxhead_get(data = data) %>%
       dplyr::filter(var %in% remaining_headings) %>%
       dplyr::pull(column_label) %>%
       unlist()
@@ -659,72 +644,60 @@ create_columns_component_h <- function(data) {
 #' @noRd
 create_body_component_h <- function(data) {
 
-  boxh <- dt_boxhead_get(data = data)
-  body <- dt_body_get(data = data)
-
   summaries_present <- dt_summary_exists(data = data)
   list_of_summaries <- dt_summary_df_get(data = data)
   groups_rows_df <- dt_groups_rows_get(data = data)
-  stub_components <- dt_stub_components(data = data)
 
   styles_tbl <- dt_styles_get(data = data)
 
-  n_data_cols <- length(dt_boxhead_get_vars_default(data = data))
-  n_rows <- nrow(body)
+  # Get effective number of columns
+  n_cols_total <- get_effective_number_of_columns(data = data)
 
-  # Get the column alignments for the data columns (this
-  # doesn't include the stub alignment)
-  col_alignment <- boxh[boxh$type == "default", ][["column_align"]]
+  # Get the number of columns for the body cells only
+  n_data_cols <- get_number_of_visible_data_columns(data = data)
 
-  # Determine whether the stub is available through analysis
-  # of the `stub_components`
-  stub_available <- dt_stub_components_has_rowname(stub_components)
+  # Get vector representation of stub layout
+  stub_layout <- get_stub_layout(data = data)
 
-  # Obtain all of the visible (`"default"`), non-stub
-  # column names for the table
-  default_vars <- dt_boxhead_get_vars_default(data = data)
+  has_stub_column <- "rowname" %in% stub_layout
 
-  all_default_vals <- unname(as.matrix(body[, default_vars]))
+  # Get a matrix of all cells in the body (not including summary cells)
+  cell_matrix <- get_body_component_cell_matrix(data = data)
+
+  # Get the number of rows in the body
+  n_rows <- nrow(cell_matrix)
+
+  # Get the column alignments and also the alignment class names
+  col_alignment <-
+    c(
+      rep("right", length(stub_layout)),
+      dt_boxhead_get_vars_align_default(data = data)
+    )
 
   alignment_classes <- paste0("gt_", col_alignment)
 
-  if (stub_available) {
-
-    n_cols <- n_data_cols + 1
-
-    alignment_classes <- c("gt_left", alignment_classes)
-
-    stub_var <- dt_boxhead_get_var_stub(data = data)
-    all_stub_vals <- as.matrix(body[, stub_var])
-
-  } else {
-    n_cols <- n_data_cols
-  }
-
   # Define function to get a character vector of formatted cell
   # data (this includes the stub, if it is present)
   output_df_row_as_vec <- function(i) {
 
-    default_vals <- all_default_vals[i, ]
+    cell_matrix <- cell_matrix[i, ]
 
-    if (stub_available) {
-      default_vals <- c(all_stub_vals[i], default_vals)
+    if (
+      "group_label" %in% stub_layout &&
+      !(i %in% groups_rows_df$row_start)
+      ) {
+        cell_matrix <- cell_matrix[-1]
     }
 
-    default_vals
+    cell_matrix
   }
 
-  # Get the sequence of column numbers in the table body (these
-  # are the visible columns in the table exclusive of the stub)
-  column_series <- seq(n_cols)
-
   # Replace an NA group with an empty string
   if (any(is.na(groups_rows_df$group_label))) {
 
     groups_rows_df <-
       groups_rows_df %>%
-      dplyr::mutate(group_label = ifelse(is.na(group_label), "", group_label)) %>%
-      dplyr::mutate(group_label = gsub("^NA", "\u2014", group_label))
+      dplyr::mutate(group_label = ifelse(is.na(group_label), "", group_label))
   }
 
   # Is the stub to be striped?
@@ -741,31 +714,24 @@ create_body_component_h <- function(data) {
       option = "row_striping_include_table_body"
     )
 
-  extra_classes_1 <- rep_len(list(NULL), n_cols)
+  extra_classes_1 <- rep_len(list(NULL), n_cols_total)
 
   extra_classes_2 <-
-    rep_len(list(if (table_body_striped) "gt_striped" else NULL), n_cols)
+    rep_len(list(if (table_body_striped) "gt_striped" else NULL), n_cols_total)
 
-  if (stub_available) {
+  if (length(stub_layout) > 0) {
 
-    extra_classes_1[[1]] <- "gt_stub"
+    if ("rowname" %in% stub_layout) {
+      row_label_col <- which(stub_layout == "rowname")
 
-    extra_classes_2[[1]] <-
-      c("gt_stub", if (table_stub_striped) "gt_striped" else NULL)
+      extra_classes_1[[row_label_col]] <- "gt_stub"
+      extra_classes_2[[row_label_col]] <-
+        c("gt_stub", if (table_stub_striped) "gt_striped" else NULL)
+    }
   }
 
-  has_tbl_body_styles <- any(c("stub", "data") %in% styles_tbl$locname)
-  has_row_group_styles <- "row_groups" %in% styles_tbl$locname
-
-  if (has_tbl_body_styles) {
-    styles_tbl_body <- subset(styles_tbl, locname %in% c("stub", "data"))
-  } else {
-    row_styles <- rep_len(list(NULL), n_cols)
-  }
-
-  if (has_row_group_styles) {
-    styles_tbl_row_groups <- subset(styles_tbl, locname == "row_groups")
-  }
+  # Create a default vector of row span values for group labels as a column
+  row_span_vals <- rep_len(list(NULL), n_cols_total)
 
   body_rows <-
     lapply(
@@ -774,36 +740,21 @@ create_body_component_h <- function(data) {
 
         body_section <- list()
 
+        group_info <- groups_rows_df[groups_rows_df$row_start == i, c("group_id", "group_label")]
+        if (nrow(group_info) == 0) {
+          group_info <- NULL
+        }
+        group_id <- group_info[["group_id"]]
+        group_label <- group_info[["group_label"]]
+
         #
         # Create a group heading row
         #
-        if (!is.null(groups_rows_df) && i %in% groups_rows_df$row_start) {
-
-          group_id <-
-            groups_rows_df[
-              which(groups_rows_df$row_start %in% i), "group_id"
-            ][[1]]
-
-          group_label <-
-            groups_rows_df[
-              which(groups_rows_df$row_start %in% i), "group_label"
-            ][[1]]
-
-          if (has_row_group_styles) {
-
-            styles_row <-
-              styles_tbl_row_groups[styles_tbl_row_groups$grpname == group_id, ]
-
-            row_style <-
-              if (nrow(styles_row) > 0) {
-                styles_row$html_style
-              } else {
-                NULL
-              }
-
-          } else {
-            row_style <- NULL
-          }
+        if (
+          !is.null(group_id) &&
+          !("group_label" %in% stub_layout)
+        ) {
+          row_style <- dt_styles_pluck(styles_tbl, locname = "row_groups", grpname = group_id)$html_style
 
           group_class <-
             if (group_label == "") {
@@ -816,7 +767,7 @@ create_body_component_h <- function(data) {
             htmltools::tags$tr(
               class = "gt_group_heading_row",
               htmltools::tags$td(
-                colspan = n_cols,
+                colspan = n_cols_total,
                 class = group_class,
                 style = row_style,
                 htmltools::HTML(group_label)
@@ -832,42 +783,108 @@ create_body_component_h <- function(data) {
 
         extra_classes <- if (i %% 2 == 0) extra_classes_2 else extra_classes_1
 
-        if (has_tbl_body_styles) {
+        styles_row <- dt_styles_pluck(styles_tbl, locname = c("data", "stub"), rownum = i)
 
-          styles_row <-
-            styles_tbl_body[styles_tbl_body$rownum == i, ]
+        row_styles <-
+          build_row_styles(
+            styles_resolved_row = styles_row,
+            include_stub = has_stub_column,
+            n_cols = n_data_cols
+          )
 
-          row_styles <-
-            build_row_styles(
-              styles_resolved_row = styles_row,
-              stub_available = stub_available,
-              n_cols = n_cols
-            )
+        if ("group_label" %in% stub_layout) {
+
+          if (i %in% groups_rows_df$row_start) {
+
+            # Modify the `extra_classes` list to include a class for
+            # the row group column
+            extra_classes[[1]] <- "gt_stub_row_group"
+
+            # Obtain a one-row table that contains the beginning and
+            # ending row index for the row group
+            row_limits <-
+              groups_rows_df %>%
+              dplyr::filter(row_start == i) %>%
+              dplyr::select(group_id, row_start, row_end)
+
+            summary_rows_group_df <-
+              list_of_summaries[["summary_df_display_list"]][[row_limits$group_id]]
+
+            if (!is.null(summary_rows_group_df) && "rowname" %in% stub_layout) {
+              summary_row_count <- nrow(summary_rows_group_df)
+            } else {
+              summary_row_count <- 0L
+            }
+
+            # Modify the `row_span_vals` list such that the first
+            # element (the row group column) contains the number of rows to span
+            row_span_vals[[1]] <- row_limits$row_end - row_limits$row_start + 1 + summary_row_count
+
+            # Process row group styles if there is an indication that some
+            # are present
+            row_group_style <- dt_styles_pluck(styles_tbl, locname = "row_groups", grpname = group_id)$html_style
+            # Add style of row group cell to vector
+            row_styles <- c(list(row_group_style), row_styles)
+
+          } else {
+
+            # Remove first element of `alignment_classes` vector
+            alignment_classes <- alignment_classes[-1]
+            row_span_vals[[1]] <- NULL
+            extra_classes[[1]] <- NULL
+          }
         }
 
         body_row <-
           htmltools::tags$tr(
-            htmltools::HTML(paste0(collapse = "\n", mapply(
-              SIMPLIFY = FALSE,
-              USE.NAMES = FALSE,
-              output_df_row_as_vec(i),
-              alignment_classes,
-              extra_classes,
-              row_styles,
-              FUN = function(x, alignment_class, extra_class, cell_style) {
-                sprintf(
-                  "<td class=\"%s\"%s>%s</td>",
-                  paste(c("gt_row", alignment_class, extra_class),
-                        collapse = " "),
-                  if (is.null(cell_style)) {
-                    ""
-                  } else {
-                    paste0(" style=\"", cell_style, "\"")
-                  },
-                  as.character(x)
-                )
-              }
-            )))
+            class = if (!is.null(group_info)) "gt_row_group_first",
+            htmltools::HTML(
+              paste0(
+                mapply(
+                  SIMPLIFY = FALSE,
+                  USE.NAMES = FALSE,
+                  output_df_row_as_vec(i = i),
+                  row_span_vals,
+                  alignment_classes,
+                  extra_classes,
+                  row_styles,
+                  FUN = function(x, row_span, alignment_class, extra_class, cell_style) {
+
+                    sprintf(
+                      "<td %sclass=\"%s\"%s>%s</td>",
+                      if (is.null(row_span)) {
+                        ""
+                      } else {
+                        paste0(
+                          "rowspan=\"",
+                          htmltools::htmlEscape(row_span, attribute = TRUE),
+                          "\" "
+                        )
+                      },
+                      paste(
+                        c(
+                          "gt_row",
+                          htmltools::htmlEscape(alignment_class, attribute = TRUE),
+                          htmltools::htmlEscape(extra_class, attribute = TRUE)
+                        ),
+                        collapse = " "
+                      ),
+                      if (!any(nzchar(cell_style))) {
+                        ""
+                      } else {
+                        paste0(
+                          " style=\"",
+                          htmltools::htmlEscape(cell_style, attribute = TRUE),
+                          "\""
+                        )
+                      },
+                      as.character(x)
+                    )
+                  }
+                ),
+                collapse = "\n"
+              )
+            )
           )
 
         body_section <- append(body_section, list(body_row))
@@ -886,15 +903,9 @@ create_body_component_h <- function(data) {
             ]
 
           summary_section <-
-            summary_row_tags(
-              list_of_summaries = list_of_summaries,
-              boxh = boxh,
-              group_id = group_id,
-              styles_resolved = styles_tbl,
-              locname = "summary_cells",
-              first_row_class = "gt_first_summary_row",
-              summary_row_class = "gt_summary_row",
-              col_alignment = col_alignment
+            summary_row_tags_i(
+              data = data,
+              group_id = group_id
             )
 
           body_section <- append(body_section, summary_section)
@@ -914,15 +925,9 @@ create_body_component_h <- function(data) {
       grand_summary_col %in% names(list_of_summaries$summary_df_display_list)) {
 
     grand_summary_section <-
-      summary_row_tags(
-        list_of_summaries = list_of_summaries,
-        boxh = boxh,
-        group_id = grand_summary_col,
-        styles_resolved = styles_tbl,
-        locname = "grand_summary_cells",
-        first_row_class = "gt_first_grand_summary_row",
-        summary_row_class = "gt_grand_summary_row",
-        col_alignment = col_alignment
+      summary_row_tags_i(
+        data = data,
+        group_id = grand_summary_col
       )
 
     body_rows <- c(body_rows, grand_summary_section)
@@ -939,26 +944,16 @@ create_body_component_h <- function(data) {
 #' @noRd
 create_source_notes_component_h <- function(data) {
 
-  source_note <- dt_source_notes_get(data = data)
+  source_notes <- dt_source_notes_get(data = data)
 
-  if (is.null(source_note)) {
+  if (is.null(source_notes)) {
     return("")
   }
 
-  stub_components <- dt_stub_components(data = data)
-
   styles_tbl <- dt_styles_get(data = data)
 
-  n_data_cols <- length(dt_boxhead_get_vars_default(data = data))
-
-  # Determine whether the stub is available
-  stub_available <- dt_stub_components_has_rowname(stub_components = stub_components)
-
-  if (stub_available) {
-    n_cols <- n_data_cols + 1
-  } else {
-    n_cols <- n_data_cols
-  }
+  # Get effective number of columns
+  n_cols_total <- get_effective_number_of_columns(data = data)
 
   # Get the style attrs for the source notes
   if ("source_notes" %in% styles_tbl$locname) {
@@ -976,20 +971,55 @@ create_source_notes_component_h <- function(data) {
     source_notes_styles <- NULL
   }
 
-  htmltools::tags$tfoot(
-    class = "gt_sourcenotes",
-    lapply(
-      source_note,
-      function(x) {
-        htmltools::tags$tr(
-          htmltools::tags$td(
-            class = "gt_sourcenote",
-            style = source_notes_styles,
-            colspan = n_cols,
-            htmltools::HTML(x)
-          )
+  # Get the source note multiline option
+  multiline <- dt_options_get_value(data = data, option = "source_notes_multiline")
+
+  # Get the source note separator option
+  separator <- dt_options_get_value(data = data, option = "source_notes_sep")
+
+  # Handle the multiline source notes case (each footnote takes up one line)
+  if (multiline) {
+
+    # Create the source notes component as a series of `<tr><td>` (one per
+    # source note) inside of a `<tfoot>`
+    return(
+      htmltools::tags$tfoot(
+        class = "gt_sourcenotes",
+        lapply(
+          source_notes,
+          function(x) {
+            htmltools::tags$tr(
+              htmltools::tags$td(
+                class = "gt_sourcenote",
+                style = source_notes_styles,
+                colspan = n_cols_total,
+                htmltools::HTML(x)
+              )
+            )
+          }
         )
-      }
+      )
+    )
+  }
+
+  # Perform HTML escaping on the separator text and transform space
+  # characters to non-breaking spaces
+  separator <- gsub(" (?= )", "&nbsp;", separator, perl = TRUE)
+
+  # Create the source notes component as a single `<tr><td>` inside
+  # of a `<tfoot>`
+  htmltools::tags$tfoot(
+    htmltools::tags$tr(
+      class = "gt_sourcenotes",
+      style = source_notes_styles,
+      htmltools::tags$td(
+        class = "gt_sourcenote",
+        colspan = n_cols_total,
+        htmltools::tags$div(
+          style = htmltools::css(`padding-bottom` = "2px"),
+          htmltools::HTML(paste(source_notes, collapse = separator))
+        )
+      )
     )
   )
 }
@@ -1007,20 +1037,10 @@ create_footnotes_component_h <- function(data) {
     return("")
   }
 
-  stub_components <- dt_stub_components(data = data)
-
   styles_tbl <- dt_styles_get(data = data)
 
-  n_data_cols <- length(dt_boxhead_get_vars_default(data = data))
-
-  # Determine whether the stub is available
-  stub_available <- dt_stub_components_has_rowname(stub_components = stub_components)
-
-  if (stub_available) {
-    n_cols <- n_data_cols + 1
-  } else {
-    n_cols <- n_data_cols
-  }
+  # Get effective number of columns
+  n_cols_total <- get_effective_number_of_columns(data = data)
 
   footnotes_tbl <-
     footnotes_tbl %>%
@@ -1042,159 +1062,326 @@ create_footnotes_component_h <- function(data) {
     footnotes_styles <- NULL
   }
 
+  # Get the footnote multiline option
+  multiline <- dt_options_get_value(data = data, option = "footnotes_multiline")
+
   # Get the footnote separator option
   separator <- dt_options_get_value(data = data, option = "footnotes_sep")
 
+  # Obtain vectors of footnote ID values (prerendered glyphs) and
+  # the associated text
   footnote_ids <- footnotes_tbl[["fs_id"]]
   footnote_text <- footnotes_tbl[["footnotes"]]
 
-  # Create the footnotes component
+  # Create a vector of HTML footnotes
+  footnotes <-
+    unlist(
+      mapply(
+        SIMPLIFY = FALSE,
+        USE.NAMES = FALSE,
+        footnote_ids,
+        footnote_text,
+        FUN = function(x, footnote_text) {
+          as.character(
+            htmltools::tagList(
+              htmltools::HTML(
+                paste0(
+                  footnote_mark_to_html(x),
+                  " ",
+                  process_text(footnote_text, context = "html")
+                ),
+                .noWS = c("after", "before")
+              )
+            )
+          )
+        }
+      )
+    )
+
+  # Handle the multiline footnotes case (each footnote takes up one line)
+  if (multiline) {
+
+    # Create the footnotes component as a series of `<tr><td>` (one per
+    # footnote) inside of a `<tfoot>`
+    return(
+      htmltools::tags$tfoot(
+        class = "gt_footnotes",
+        lapply(
+          footnotes,
+          function(x) {
+            htmltools::tags$tr(
+              htmltools::tags$td(
+                class = "gt_footnote",
+                style = footnotes_styles,
+                colspan = n_cols_total,
+                htmltools::HTML(x)
+              )
+            )
+          }
+        )
+      )
+    )
+  }
+
+  # Perform HTML escaping on the separator text and transform space
+  # characters to non-breaking spaces
+  separator <- gsub(" (?= )", "&nbsp;", separator, perl = TRUE)
+
+  # Create the footnotes component as a single `<tr><td>` inside
+  # of a `<tfoot>`
   htmltools::tags$tfoot(
     htmltools::tags$tr(
       class = "gt_footnotes",
       style = footnotes_styles,
       htmltools::tags$td(
-        colspan = n_cols,
-        mapply(
-          SIMPLIFY = FALSE,
-          USE.NAMES = FALSE,
-          footnote_ids,
-          footnote_text,
-          FUN = function(x, footnote_text) {
-
-            htmltools::tags$p(
-              class = "gt_footnote",
-              htmltools::tags$sup(
-                class = "gt_footnote_marks",
-                htmltools::tags$em(
-                  x
-                )
-              ),
-              " ",
-              htmltools::HTML(footnote_text),
-              htmltools::HTML(separator)
-            )
-          }
+        class = "gt_footnote",
+        colspan = n_cols_total,
+        htmltools::tags$div(
+          style = htmltools::css(`padding-bottom` = "2px"),
+          htmltools::HTML(paste(footnotes, collapse = separator))
         )
       )
     )
   )
 }
 
-summary_row_tags <- function(list_of_summaries,
-                             boxh,
-                             group_id,
-                             styles_resolved,
-                             locname,
-                             first_row_class,
-                             summary_row_class,
-                             col_alignment) {
+# Get a matrix of all body cells
+get_body_component_cell_matrix <- function(data) {
+
+  body <- dt_body_get(data = data)
+  stub_layout <- get_stub_layout(data = data)
+  default_vars <- dt_boxhead_get_vars_default(data = data)
+
+  body_matrix <- unname(as.matrix(body[, default_vars]))
+
+  if (length(stub_layout) == 0) {
+    return(body_matrix)
+  }
+
+  if ("rowname" %in% stub_layout) {
+
+    body_matrix <-
+      cbind(
+        unname(as.matrix(body[, dt_boxhead_get_var_stub(data = data)])),
+        body_matrix
+      )
+  }
+
+  if ("group_label" %in% stub_layout) {
+
+    groups_rows_df <-
+      dt_groups_rows_get(data = data) %>%
+      dplyr::select(group_id, group_label, row_start)
+
+    group_label_matrix <-
+      dt_stub_df_get(data = data) %>%
+      dplyr::select(-rowname, -group_label) %>%
+      dplyr::inner_join(groups_rows_df, by = "group_id") %>%
+      dplyr::mutate(
+        row = dplyr::row_number(),
+        built = dplyr::if_else(row_start != row, "", built)
+      ) %>%
+      dplyr::select(built) %>%
+      as.matrix %>%
+      unname()
+
+    body_matrix <- cbind(group_label_matrix, body_matrix)
+  }
+
+  body_matrix
+}
+
+summary_row_tags_i <- function(data,
+                               group_id) {
+
+  # Check that `group_id` isn't NULL and that length is exactly 1
+  if (is.null(group_id) || length(group_id) != 1) {
+    stop("`group_id` cannot be NULL and must be of length 1.")
+  }
+
+  list_of_summaries <- dt_summary_df_get(data = data)
+  styles_tbl <- dt_styles_get(data = data)
 
   # Obtain all of the visible (`"default"`), non-stub column names
   # for the table from the `boxh` object
-  default_vars <- boxh[boxh$type == "default", "var", drop = TRUE]
+  default_vars <- dt_boxhead_get_vars_default(data = data)
+
+  stub_layout <- get_stub_layout(data = data)
+
+  stub_is_2 <- length(stub_layout) > 1
 
   summary_row_lines <- list()
 
-  if (group_id %in% names(list_of_summaries$summary_df_display_list)) {
+  # In the below conditions
+  # - `grand_summary_col` is a global variable (`"::GRAND_SUMMARY"`, assigned
+  #   in `dt_summary.R`)
+  # - `group_id` might be passed in as NA when there are unnamed groups (this
+  #   can happen usually when using `tab_row_group()` to build these row groups)
+  #   and you cannot create summary rows for unnamed groups
+  if (is.na(group_id)) {
+    return(summary_row_lines)
+  } else if (
+      group_id %in% names(list_of_summaries$summary_df_display_list) &&
+      group_id != grand_summary_col
+  ) {
+    summary_row_type <- "group"
+  } else if (group_id == grand_summary_col) {
+    summary_row_type <- "grand"
+  } else {
+    return(summary_row_lines)
+  }
 
-    # Obtain the summary data table specific to the group ID and
-    # select the column named `rowname` and all of the visible columns
-    summary_df <-
-      list_of_summaries$summary_df_display_list[[group_id]] %>%
-      dplyr::select(.env$rowname_col_private, .env$default_vars)
+  # Obtain the summary data table specific to the group ID and
+  # select the column named `rowname` and all of the visible columns
+  summary_df <-
+    list_of_summaries$summary_df_display_list[[group_id]] %>%
+    dplyr::select(.env$rowname_col_private, .env$default_vars)
 
-    n_cols <- ncol(summary_df)
+  # Get effective number of columns
+  n_cols_total <- get_effective_number_of_columns(data = data)
 
-    summary_df_row <- function(j) {
-      unname(unlist(summary_df[j, ]))
+  # Get the number of columns for the body cells only
+  n_data_cols <- get_number_of_visible_data_columns(data = data)
+
+  if (stub_is_2) {
+    n_cols_total <- n_cols_total - 1
+  }
+
+  extra_classes <- rep_len(list(NULL), n_cols_total)
+  extra_classes[[1]] <- "gt_stub"
+
+  # Create a default list of colspan values for the summary row
+  col_span_vals <- rep_len(list(NULL), n_cols_total)
+
+  if (stub_is_2 && summary_row_type == "grand") {
+    col_span_vals[[1]] <- 2L
+  }
+
+  # Get the column alignments and also the alignment class names
+  col_alignment <-
+    c("right", dt_boxhead_get_vars_align_default(data = data))
+  alignment_classes <- paste0("gt_", col_alignment)
+
+  for (j in seq_len(nrow(summary_df))) {
+
+    last_row_class <- "gt_last_summary_row"
+
+    if (summary_row_type == "grand") {
+
+      styles_resolved_row <- dt_styles_pluck(styles_tbl, locname = "grand_summary_cells", grpname = group_id, rownum = j)
+      summary_row_class <- "gt_grand_summary_row"
+      first_row_class <- "gt_first_grand_summary_row"
+
+    } else {
+
+      styles_resolved_row <- dt_styles_pluck(styles_tbl, locname = "summary_cells", grpname = group_id, grprow = j)
+      summary_row_class <- "gt_summary_row"
+      first_row_class <- if ("rowname" %in% stub_layout) "gt_first_summary_row thick" else "gt_first_summary_row"
     }
 
-    stub_classes <- rep_len(list(NULL), n_cols)
-    stub_classes[[1]] <- "gt_stub"
+    row_styles <-
+      build_row_styles(
+        styles_resolved_row = styles_resolved_row,
+        include_stub = TRUE,
+        n_cols = n_data_cols
+      )
 
-    alignment_classes <- c("gt_right", paste0("gt_", col_alignment))
+    summary_row_lines[[length(summary_row_lines) + 1]] <-
+      htmltools::tags$tr(
+        htmltools::HTML(
+          paste0(
+            mapply(
+              SIMPLIFY = FALSE,
+              USE.NAMES = FALSE,
+              unname(unlist(summary_df[j, ])),
+              col_span_vals,
+              alignment_classes,
+              extra_classes,
+              row_styles,
+              FUN = function(x, col_span, alignment_class, extra_class, cell_style) {
 
-    styles_resolved_group <-
-      dplyr::filter(
-        styles_resolved,
-        grpname == .env$group_id,
-        locname == .env$locname
-      ) %>%
-      dplyr::mutate(grprow = round((rownum %% 1) * 100))
+                extra_class <- c(extra_class, summary_row_class)
 
-    for (j in seq_len(nrow(summary_df))) {
+                if (j == 1) {
+                  extra_class <- c(extra_class, first_row_class)
+                }
 
-      if (group_id == grand_summary_col) {
+                if (j == nrow(summary_df)) {
+                  extra_class <- c(extra_class, last_row_class)
+                }
 
-        # In the above condition, `grand_summary_col` is a global variable
-        # (`"::GRAND_SUMMARY"`) assigned in `dt_summary.R`)
-
-        styles_resolved_row <-
-          styles_resolved_group[styles_resolved_group$rownum == j, , drop = FALSE]
-
-      } else {
-
-        styles_resolved_row <-
-          styles_resolved_group[styles_resolved_group$grprow == j, , drop = FALSE]
-      }
-
-      row_styles <-
-        build_row_styles(
-          styles_resolved_row = styles_resolved_row,
-          stub_available = TRUE,
-          n_cols = n_cols
-        )
-
-      summary_row_lines[[length(summary_row_lines) + 1]] <-
-        htmltools::tags$tr(
-          mapply(
-            SIMPLIFY = FALSE,
-            USE.NAMES = FALSE,
-            summary_df_row(j),
-            stub_classes,
-            alignment_classes,
-            row_styles,
-            FUN = function(x, stub_class, alignment_class, cell_style) {
-
-              if (j == 1) {
-                summary_row_class <- c(summary_row_class, first_row_class)
+                sprintf(
+                  "<td %sclass=\"%s\"%s>%s</td>",
+                  if (is.null(col_span)) {
+                    ""
+                  } else {
+                    paste0(
+                      "colspan=\"",
+                      htmltools::htmlEscape(col_span, attribute = TRUE),
+                      "\" ")
+                  },
+                  htmltools::htmlEscape(
+                    paste(
+                      c("gt_row", alignment_class, extra_class),
+                      collapse = " "
+                    ),
+                    attribute = TRUE
+                  ),
+                  if (!any(nzchar(cell_style))) {
+                    ""
+                  } else {
+                    paste0(
+                      " style=\"",
+                      htmltools::htmlEscape(cell_style, attribute = TRUE),
+                      "\""
+                    )
+                  },
+                  as.character(x)
+                )
               }
-
-              htmltools::tags$td(
-                class = paste(
-                  c("gt_row", stub_class, alignment_class, summary_row_class),
-                  collapse = " "
-                ),
-                style = cell_style,
-                htmltools::HTML(x)
-              )
-            }
+            ),
+            collapse = "\n"
           )
         )
-    }
+      )
   }
 
   summary_row_lines
 }
 
 build_row_styles <- function(styles_resolved_row,
-                             stub_available,
+                             include_stub,
                              n_cols) {
+  # The styles_resolved_row data frame should contain the columns `colnum` and
+  # `html_style`. Each colnum should match the number of a data column in the
+  # output table; the first data column is number 1. No colnum should appear
+  # more than once in styles_resolved_row. It's OK for a column not to appear in
+  # styles_resolved_row, and it's OK for styles_resolved_row to have 0 rows.
+  #
+  # If `include_stub` is TRUE, then a row with column==0 will be used as the
+  # stub style.
 
-  row_styles <- rep_len(list(NULL), n_cols)
-
-  if (nrow(styles_resolved_row) > 0) {
-    if (!stub_available) {
-      row_styles[styles_resolved_row$colnum] <-
-        styles_resolved_row$html_style
-    } else {
-      row_styles[styles_resolved_row$colnum + 1] <-
-        styles_resolved_row$html_style
-    }
+  # This function's implementation can't tolerate colnum of NA, or illegal
+  # colnum values. Check and throw early.
+  if (!isTRUE(all(styles_resolved_row$colnum %in% c(0, seq_len(n_cols)))) ||
+      any(duplicated(styles_resolved_row$colnum))) {
+    stop("build_row_styles was called with invalid colnum values")
   }
 
-  row_styles
+  # This will hold the resulting styles
+  result <- rep_len(list(NULL), n_cols)
+
+  # The subset of styles_resolved_row that applies to data
+  data_styles <- styles_resolved_row[styles_resolved_row$colnum > 0,]
+  result[data_styles$colnum] <- data_styles$html_style
+
+  # If a stub exists, we need to prepend a style (or NULL) to the result.
+  if (include_stub) {
+    stub_style <- styles_resolved_row[styles_resolved_row$colnum == 0,]
+    result <- c(list(stub_style$html_style), result)
+  }
+
+  result
 }
 
 as_css_font_family_attr <- function(font_vec, value_only = FALSE) {
