@@ -10,7 +10,6 @@ latex_packages <- function() {
 
 # Transform a footnote mark to a LaTeX representation as a superscript
 footnote_mark_to_latex <- function(mark) {
-
   paste0("\\textsuperscript{", mark, "}")
 }
 
@@ -55,19 +54,33 @@ latex_group_row <- function(group_name,
 #' @noRd
 create_table_start_l <- function(data) {
 
-  col_alignment <-
-    dt_boxhead_get(data = data) %>%
-    dplyr::filter(type == "default") %>%
-    dplyr::pull(column_align)
+  # Get vector representation of stub layout
+  stub_layout <- get_stub_layout(data = data)
 
-  # TODO: ensure that number of alignment tabs is correct
-  if (dt_stub_df_exists(data = data)) {
-    col_alignment <- c("left", col_alignment)
+  # Get default alignments for body columns
+  col_alignment <- dt_boxhead_get_vars_align_default(data = data)
+
+  # Determine if there are any footnotes or source notes; if any,
+  # add a `\setlength` command that will pull up the minipage environment
+  # for the footnotes block
+  if (
+    nrow(dt_footnotes_get(data = data)) > 0 ||
+    length(dt_source_notes_get(data = data)) > 0
+  ) {
+    longtable_post_length <- "\\setlength{\\LTpost}{0mm}\n"
+  } else {
+    longtable_post_length <- ""
   }
 
+  # Generate setup statements for table including default right
+  # alignments and vertical lines for any stub columns
   paste0(
     "\\captionsetup[table]{labelformat=empty,skip=1pt}\n",
+    longtable_post_length,
     "\\begin{longtable}{",
+    if (length(stub_layout) > 0) {
+      paste0(rep("r|", length(stub_layout)), collapse = "")
+    },
     col_alignment %>% substr(1, 1) %>% paste(collapse = ""),
     "}\n",
     collapse = ""
@@ -150,35 +163,31 @@ create_columns_component_l <- function(data) {
 
   boxh <- dt_boxhead_get(data = data)
   stubh <- dt_stubhead_get(data = data)
-  stub_available <- dt_stub_df_exists(data = data)
+
+  # Get vector representation of stub layout
+  stub_layout <- get_stub_layout(data = data)
+
+  # Determine if there are any spanners present
   spanners_present <- dt_spanners_exists(data = data)
 
-  # Get the headings
-  #headings <- boxh$column_label %>% unlist()
-
-  headings_vars <- boxh %>% dplyr::filter(type == "default") %>% dplyr::pull(var)
+  # Get the column headings
+  headings_vars <- dt_boxhead_get_vars_default(data = data)
   headings_labels <- dt_boxhead_get_vars_labels_default(data = data)
 
-  # TODO: Implement hidden boxhead in LaTeX
-  # # Should the column labels be hidden?
-  # column_labels_hidden <-
-  #   dt_options_get_value(data = data, option = "column_labels_hidden")
-  #
-  # if (column_labels_hidden) {
-  #   return("")
-  # }
+  # If there is a stub then modify the `headings_vars` and `headings_labels`
+  if (length(stub_layout) > 0) {
 
-  # If `stub_available` == TRUE, then replace with a set stubhead
-  # label or nothing
-  if (isTRUE(stub_available) && length(stubh$label) > 0) {
-
-    headings_labels <- prepend_vec(headings_labels, stubh$label)
     headings_vars <- prepend_vec(headings_vars, "::stub")
 
-  } else if (isTRUE(stub_available)) {
+    stub_label <- ifelse(length(stubh$label) > 0, stubh$label, "")
 
-    headings_labels <- prepend_vec(headings_labels, "")
-    headings_vars <- prepend_vec(headings_vars, "::stub")
+    if (length(stub_layout) > 0) {
+
+      stub_label <-
+        paste0("\\multicolumn{", length(stub_layout), "}{l}{", stub_label, "}")
+    }
+
+    headings_labels <- prepend_vec(headings_labels, stub_label)
   }
 
   table_col_headings <-
@@ -190,9 +199,9 @@ create_columns_component_l <- function(data) {
     spanners <- dt_spanners_print(data = data, include_hidden = FALSE)
     spanner_ids <- dt_spanners_print(data = data, include_hidden = FALSE, ids = TRUE)
 
-    if (stub_available) {
-      spanners <- c(NA_character_, spanners)
-      spanner_ids <- c(NA_character_, spanner_ids)
+    if (length(stub_layout) > 0) {
+      spanners <- c(rep(NA_character_, length(stub_layout)), spanners)
+      spanner_ids <- c(rep(NA_character_, length(stub_layout)), spanner_ids)
     }
 
     spanners_rle <- unclass(rle(spanner_ids))
@@ -219,10 +228,24 @@ create_columns_component_l <- function(data) {
         )
       )
 
+    # If there is a stub we need to tweak the spanners row with a blank
+    # multicolumn statement that's the same width as that in the columns
+    # row; this is to prevent the automatic vertical line that would otherwise
+    # appear here
+    if (length(stub_layout) > 0) {
+
+      multicol <-
+        c(
+          paste0("\\multicolumn{", length(stub_layout), "}{l}{}"),
+          multicol[-seq_along(stub_layout)]
+        )
+    }
+
     multicol <- paste0(paste(multicol, collapse = " & "), " \\\\ \n")
     cmidrule <- paste0(paste(cmidrule, collapse = " "), "\n")
 
-    table_col_spanners <- paste(multicol, cmidrule, collapse = "")
+    table_col_spanners <- paste0(multicol, cmidrule, collapse = "")
+
 
   } else {
     table_col_spanners <- ""
@@ -237,37 +260,21 @@ create_body_component_l <- function(data) {
   body <- dt_body_get(data = data)
   boxh <- dt_boxhead_get(data = data)
 
-  list_of_summaries <- dt_summary_df_get(data = data)
-  summaries_present <- dt_summary_exists(data = data)
   groups_rows_df <- dt_groups_rows_get(data = data)
-  stub_components <- dt_stub_components(data = data)
 
-  # Obtain the `styles_tbl` (NOTE: this is currently unused)
-  styles_tbl <- dt_styles_get(data = data)
-
-  n_data_cols <- length(dt_boxhead_get_vars_default(data = data))
   n_rows <- nrow(body)
 
-  # Determine whether the stub is available
-  stub_available <- dt_stub_components_has_rowname(stub_components = stub_components)
+  # Get vector representation of stub layout
+  stub_layout <- get_stub_layout(data = data)
 
   # Obtain all of the visible (`"default"`), non-stub
   # column names for the table
   default_vars <- dt_boxhead_get_vars_default(data = data)
 
-  # Split `body_content` by slices of rows in cases where there is
-  # and isn't a stub present
-  if (stub_available) {
-
-    stub_var <- dt_boxhead_get_var_stub(data = data)
-    row_splits_body <- split_row_content(body[, c(stub_var, default_vars)])
-
-  } else {
-
-    row_splits_body <- split_row_content(body[, default_vars])
-  }
-
-  # Create a vector body rows
+  # Get a matrix of body cells to render, split into a list of
+  # character vectors by row, and create a vector of LaTeX body rows
+  cell_matrix <- get_body_component_cell_matrix(data = data)
+  row_splits_body <- split_row_content(cell_matrix)
   body_rows <- create_body_rows_l(row_splits_body = row_splits_body)
 
   # Replace an NA group with an empty string
@@ -277,34 +284,42 @@ create_body_component_l <- function(data) {
       groups_rows_df %>%
       dplyr::mutate(
         group_label = ifelse(
-          is.na(group_label), "\\vspace*{-5mm}", group_label)) %>%
-      dplyr::mutate(
-        group_label = gsub("^NA", "\\textemdash", group_label))
+          is.na(group_label), "\\vspace*{-5mm}", group_label
+        )
+      )
   }
 
-  group_rows <-
-    create_group_rows_l(
-      groups_rows_df = groups_rows_df,
-      n_rows = n_rows
-    )
-
   summary_rows <-
     create_summary_rows_l(
-      list_of_summaries = list_of_summaries,
-      boxh = boxh,
+      data = data,
       groups_rows_df = groups_rows_df,
       n_rows = n_rows
     )
 
-  grand_summary_rows <-
-    create_grand_summary_rows_l(
-      list_of_summaries = list_of_summaries,
-      boxh = boxh
-    )
+  grand_summary_rows <- create_grand_summary_rows_l(data = data)
 
-  paste(
-    paste(
-      paste0(group_rows, body_rows, summary_rows),
+  paste0(
+    paste0(
+      if (!("group_label" %in% stub_layout)) {
+
+        group_rows <-
+          create_group_rows_l(
+            groups_rows_df = groups_rows_df,
+            n_rows = n_rows
+          )
+
+        paste0(group_rows, body_rows, summary_rows)
+
+      } else {
+
+        group_dividers <-
+          create_group_dividers_l(
+            groups_rows_df = groups_rows_df,
+            n_rows = n_rows
+          )
+
+        paste0(group_dividers, body_rows, summary_rows)
+      },
       collapse = ""
     ),
     grand_summary_rows,
@@ -322,72 +337,73 @@ create_table_end_l <- function() {
 }
 
 #' @noRd
-create_footnotes_component_l <- function(data) {
+create_footer_component_l <- function(data) {
 
   footnotes_tbl <- dt_footnotes_get(data = data)
-  opts_df <- dt_options_get(data = data)
+  source_notes_vec <- dt_source_notes_get(data = data)
 
-  # If the `footnotes_resolved` object has no
-  # rows, then return an empty footnotes component
-  if (nrow(footnotes_tbl) == 0) {
+  # If there are no footnotes or source notes, return an empty string
+  if (nrow(footnotes_tbl) == 0 && length(source_notes_vec) == 0) {
     return("")
   }
 
-  footnotes_tbl <-
-    footnotes_tbl %>%
-    dplyr::select(fs_id, footnotes) %>%
-    dplyr::distinct()
+  # Get the multiline and separator options for footnotes and source notes
+  footnotes_multiline <- dt_options_get_value(data = data, option = "footnotes_multiline")
+  footnotes_sep <- dt_options_get_value(data = data, option = "footnotes_sep")
+  source_notes_multiline <- dt_options_get_value(data = data, option = "source_notes_multiline")
+  source_notes_sep <- dt_options_get_value(data = data, option = "source_notes_sep")
 
-  # Get the separator option from `opts_df`
-  separator <-
-    opts_df %>%
-    dplyr::filter(parameter == "footnotes_sep") %>%
-    dplyr::pull(value)
+  # Create a formatted footnotes string
+  if (nrow(footnotes_tbl) > 0) {
 
-  # Convert an HTML break tag to a Latex line break
-  separator <-
-    separator %>%
-    tidy_gsub("<br\\s*?(/|)>", "\\newline") %>%
-    tidy_gsub("&nbsp;", " ")
+    footnotes_tbl <-
+      footnotes_tbl %>%
+      dplyr::select(fs_id, footnotes) %>%
+      dplyr::distinct()
 
-  # Create the footnotes block
+    # Create a vector of formatted footnotes
+    footnotes <-
+      paste0(
+        footnote_mark_to_latex(footnotes_tbl[["fs_id"]]),
+        vapply(
+          footnotes_tbl[["footnotes"]],
+          FUN.VALUE = character(1),
+          FUN = process_text,
+          context = "latex"
+        )
+      )
+
+    if (footnotes_multiline) {
+      footnotes <- paste(footnotes, collapse = "\\\\\n") %>% paste_right("\\\\\n")
+    } else {
+      footnotes <- paste(footnotes, collapse = footnotes_sep) %>% paste_right("\\\\\n")
+    }
+  } else {
+    footnotes <- ""
+  }
+
+  # Create a formatted source notes string
+  if (length(source_notes_vec) > 0) {
+
+    if (source_notes_multiline) {
+      source_notes <- paste(source_notes_vec, collapse = "\\\\\n") %>% paste_right("\\\\\n")
+    } else {
+      source_notes <- paste(source_notes_vec, collapse = source_notes_sep) %>% paste_right("\\\\\n")
+    }
+
+  } else {
+    source_notes <- ""
+  }
+
+  # Create the footer block
   paste0(
-    "\\vspace{-5mm}\n",
     "\\begin{minipage}{\\linewidth}\n",
-    paste0(
-      footnote_mark_to_latex(footnotes_tbl[["fs_id"]]),
-      footnotes_tbl[["footnotes"]] %>%
-        unescape_html() %>%
-        markdown_to_latex(), " \\\\ \n", collapse = ""),
+    paste0(footnotes, source_notes),
     "\\end{minipage}\n",
     collapse = ""
   )
 }
 
-#' @noRd
-create_source_note_component_l <- function(data) {
-
-  source_note <- dt_source_notes_get(data = data)
-
-  # If the `footnotes_resolved` object has no
-  # rows, then return an empty footnotes component
-  if (length(source_note) == 0) {
-    return("")
-  }
-
-  source_note <- source_note[[1]]
-
-  # Create the source notes block
-  source_note_component <-
-    paste0(
-      "\\begin{minipage}{\\linewidth}\n",
-      paste0(
-        source_note %>% as.character(), "\\\\ \n", collapse = ""),
-      "\\end{minipage}\n", collapse = "")
-
-  source_note_component
-}
-
 # Function to build a vector of `group` rows in the table body
 create_group_rows_l <- function(groups_rows_df,
                                 n_rows) {
@@ -397,7 +413,6 @@ create_group_rows_l <- function(groups_rows_df,
       lapply(
         seq_len(n_rows),
         FUN = function(x) {
-
           if (!(x %in% groups_rows_df$row_start)) {
             return("")
           }
@@ -414,6 +429,22 @@ create_group_rows_l <- function(groups_rows_df,
   )
 }
 
+create_group_dividers_l <- function(groups_rows_df,
+                                    n_rows) {
+
+  dividers <- rep_len("", n_rows)
+
+  # Dividing line is inserted *after* last row of each group
+  # so add 1 to `groups_rows_df$row_end`; bottom of series (outside
+  # row range) shouldn't have a dividing line
+  divider_idx <- groups_rows_df$row_end + 1
+  divider_idx <- divider_idx[divider_idx <= n_rows]
+
+  dividers[divider_idx] <- "\\midrule\n"
+
+  dividers
+}
+
 # Function to build a vector of `body` rows
 create_body_rows_l <- function(row_splits_body) {
 
@@ -430,18 +461,23 @@ create_body_rows_l <- function(row_splits_body) {
 }
 
 # Function to build a vector of `summary` rows in the table body
-create_summary_rows_l <- function(list_of_summaries,
-                                  boxh,
+create_summary_rows_l <- function(data,
                                   groups_rows_df,
                                   n_rows) {
 
+  list_of_summaries <- dt_summary_df_get(data = data)
+
   if (length(list_of_summaries) < 1) {
     return(rep_len("", n_rows))
   }
 
+  # Get vector representation of stub layout
+  stub_layout <- get_stub_layout(data = data)
+  stub_width <- length(stub_layout)
+
   # Obtain all of the visible (`"default"`), non-stub
   # column names for the table
-  default_vars <- boxh[boxh$type == "default", "var", drop = TRUE]
+  default_vars <- dt_boxhead_get_vars_default(data = data)
 
   unname(
     unlist(
@@ -474,8 +510,25 @@ create_summary_rows_l <- function(list_of_summaries,
 
           row_splits_summary <- split_row_content(summary_df)
 
+          if (stub_width > 1) {
+
+            row_splits_summary <-
+              lapply(
+                row_splits_summary,
+                function(x) {
+
+                  x <- c(rep("", stub_width - 1), x)
+
+                  x[seq_len(stub_width)] <-
+                    paste0("\\multicolumn{1}{r|}{", x[seq_len(stub_width)], "}")
+
+                  x
+                }
+              )
+          }
+
           summary_rows <-
-            paste(
+            paste0(
               vapply(
                 row_splits_summary,
                 FUN.VALUE = character(1),
@@ -485,15 +538,27 @@ create_summary_rows_l <- function(list_of_summaries,
               collapse = ""
             )
 
-          paste0(summary_h_border, summary_rows)
+          paste0(
+            if ("group_label" %in% stub_layout && stub_width > 1) {
+              paste0(
+                "\\cmidrule(l{-0.05em}r){2-",
+                ncol(summary_df) + stub_width - 1,
+                "}"
+              )
+            } else {
+              summary_h_border
+            },
+            summary_rows
+          )
         }
       )
     )
   )
 }
 
-create_grand_summary_rows_l <- function(list_of_summaries,
-                                        boxh) {
+create_grand_summary_rows_l <- function(data) {
+
+  list_of_summaries <- dt_summary_df_get(data = data)
 
   if (
     length(list_of_summaries) < 1 ||
@@ -503,9 +568,13 @@ create_grand_summary_rows_l <- function(list_of_summaries,
     return("")
   }
 
+  # Get vector representation of stub layout
+  stub_layout <- get_stub_layout(data = data)
+  stub_width <- length(stub_layout)
+
   # Obtain all of the visible (`"default"`), non-stub
   # column names for the table
-  default_vars <- boxh[boxh$type == "default", "var", drop = TRUE]
+  default_vars <- dt_boxhead_get_vars_default(data = data)
 
   grand_summary_df <-
     list_of_summaries$summary_df_display_list[[grand_summary_col]] %>%
@@ -513,6 +582,18 @@ create_grand_summary_rows_l <- function(list_of_summaries,
 
   row_splits_summary <- split_row_content(grand_summary_df)
 
+  if (stub_width > 1) {
+
+    row_splits_summary <-
+      lapply(
+        row_splits_summary,
+        function(x) {
+          x[[1]] <- paste0("\\multicolumn{", stub_width, "}{r|}{", x[1], "}")
+          x
+        }
+      )
+  }
+
   grand_summary_rows <-
     paste(
       vapply(
