@@ -837,6 +837,7 @@ create_heading_component_rtf <- function(data) {
       !dt_heading_has_subtitle(data = data)) {
     return(list())
   }
+
   # Get table components and metadata using the `data`
   boxh <- dt_boxhead_get(data)
   heading <- dt_heading_get(data)
@@ -947,50 +948,68 @@ create_heading_component_rtf <- function(data) {
 #
 create_columns_component_rtf <- function(data) {
 
-  # Get table components and metadata using the `data`
-  boxh <- dt_boxhead_get(data)
-  spanners_present <- dt_spanners_exists(data)
+  # Should the column labels be hidden?
   column_labels_hidden <- dt_options_get_value(data, option = "column_labels_hidden")
-  headings_labels <- dt_boxhead_get_vars_labels_default(data = data)
-  stub_available <- dt_stub_df_exists(data)
-  stubh_available <- dt_stubhead_has_label(data)
-
-  footnotes_tbl <- dt_footnotes_get(data) # not used currently
-
-  # Get table options
-  column_labels_border_top_color <- dt_options_get_value(data = data, option = "column_labels_border_top_color")
-  column_labels_border_bottom_color <- dt_options_get_value(data = data, option = "column_labels_border_bottom_color")
-  column_labels_vlines_color <- dt_options_get_value(data = data, option = "column_labels_vlines_color")
-  column_labels_border_lr_color <- dt_options_get_value(data = data, option = "column_labels_border_lr_color") # not used currently
-
-  # Obtain alignments for each visible column label
-  col_alignment <-
-    boxh %>%
-    dplyr::filter(type == "default") %>%
-    dplyr::pull(column_align)
-
-  # Obtain widths for each visible column label
-  col_widths <-
-    boxh %>%
-    dplyr::filter(type %in% c("default", "stub")) %>%
-    dplyr::arrange(dplyr::desc(type)) %>%
-    dplyr::pull(column_width) %>%
-    unlist()
 
   if (column_labels_hidden) {
     return(list())
   }
 
-  if (stub_available) {
-    headings_labels <- c("", headings_labels)
-    col_alignment <- c("left", col_alignment)
+  stubh <- dt_stubhead_get(data = data)
+
+  # Get vector representation of stub layout
+  stub_layout <- get_stub_layout(data = data)
+
+  # Determine if there are any spanners present
+  spanners_present <- dt_spanners_exists(data)
+
+  # Get options related to column label border colors
+  column_labels_border_top_color <- dt_options_get_value(data = data, option = "column_labels_border_top_color")
+  column_labels_border_bottom_color <- dt_options_get_value(data = data, option = "column_labels_border_bottom_color")
+  column_labels_vlines_color <- dt_options_get_value(data = data, option = "column_labels_vlines_color")
+  column_labels_border_lr_color <- dt_options_get_value(data = data, option = "column_labels_border_lr_color") # not used currently
+
+  # Get the column headings
+  headings_vars <- dt_boxhead_get_vars_default(data = data)
+  headings_labels <- dt_boxhead_get_vars_labels_default(data = data)
+
+  # Obtain alignments for each visible column label
+  col_alignment <- dt_boxhead_get_vars_align_default(data = data)
+
+  # Obtain widths for each visible column label in units of twips
+  col_widths <-
+    dt_boxhead_get(data = data) %>%
+    dplyr::filter(type %in% c("default", "stub")) %>%
+    dplyr::arrange(dplyr::desc(type)) %>%
+    dplyr::pull(column_width) %>%
+    unlist() %>%
+    col_width_resolver_rtf(
+      table_width = dt_options_get_value(data = data, option = "table_width"),
+      col_widths = .,
+      n_cols = get_effective_number_of_columns(data = data)
+    )
+
+  # Get the column headings
+  headings_labels <- dt_boxhead_get_vars_labels_default(data = data)
+
+  if (length(stub_layout) > 0) {
+
+    headings_labels <-
+      prepend_vec(
+        headings_labels,
+        c(
+          if (length(stubh$label) > 0) stubh$label else "",
+          rep("", length(stub_layout) - 1)
+        )
+      )
   }
 
-  if (stubh_available) {
-    headings_labels[1] <-
-      dt_stubhead_get(data = data) %>%
-      .$label
-  }
+  # Get the column alignments
+  col_alignment <-
+    c(
+      rep("left", length(stub_layout)),
+      dt_boxhead_get_vars_align_default(data = data)
+    )
 
   if (spanners_present) {
 
@@ -999,18 +1018,20 @@ create_columns_component_rtf <- function(data) {
 
     spanners[is.na(spanners)] <- ""
 
-    if (stub_available) {
-      spanners <- c("", spanners)
-      spanner_ids <- c("", spanner_ids)
+    if (length(stub_layout) > 0) {
+      spanners <- c(rep("", length(stub_layout)), spanners)
+      spanner_ids <- c(rep("", length(stub_layout)), spanner_ids)
     }
+
     spanners_lengths <- unclass(rle(spanner_ids))
 
-    merge_keys <- c()
+    merge_keys_spanners <- c()
+
     for (i in seq_along(spanners_lengths$lengths)) {
       if (spanners_lengths$lengths[i] == 1) {
-        merge_keys <- c(merge_keys, 0)
+        merge_keys_spanners <- c(merge_keys_spanners, 0)
       } else {
-        merge_keys <- c(merge_keys, 1, rep(2, spanners_lengths$lengths[i] - 1))
+        merge_keys_spanners <- c(merge_keys_spanners, 1, rep(2, spanners_lengths$lengths[i] - 1))
       }
     }
 
@@ -1024,7 +1045,7 @@ create_columns_component_rtf <- function(data) {
               rtf_raw(spanners[x])
             ),
             h_align = "center",
-            h_merge = merge_keys[x],
+            h_merge = merge_keys_spanners[x],
             borders = list(
               rtf_border("top", color = column_labels_border_top_color, width = 40),
               rtf_border("bottom", color = column_labels_border_bottom_color),
@@ -1038,15 +1059,13 @@ create_columns_component_rtf <- function(data) {
     spanners_list <- list()
   }
 
-  table_width <- dt_options_get_value(data = data, option = "table_width")
+  merge_keys_cells <- rep(0, get_effective_number_of_columns(data = data))
 
-  col_widths <-
-    col_width_resolver_rtf(
-      table_width = table_width,
-      col_widths = col_widths,
-      n_cols = length(headings_labels)
-    )
+  if (length(stub_layout) == 2) {
 
+    merge_keys_cells <-
+      c(1, 2, rep(0, get_effective_number_of_columns(data = data) - 2))
+  }
 
   cell_list <-
     lapply(
@@ -1058,6 +1077,7 @@ create_columns_component_rtf <- function(data) {
             rtf_raw(headings_labels[x])
           ),
           h_align = col_alignment[x],
+          h_merge = merge_keys_cells[x],
           borders = list(
             rtf_border("top", color = column_labels_border_top_color, width = 40),
             rtf_border("bottom", color = column_labels_border_bottom_color, width = 40),
@@ -1108,21 +1128,9 @@ create_columns_component_rtf <- function(data) {
 #
 create_body_component_rtf <- function(data) {
 
-  # Get table components and metadata using the `data`
-  body <- dt_body_get(data)
-  boxh <- dt_boxhead_get(data)
-  stubh <- dt_stubhead_get(data)
-  opts_df <- dt_options_get(data)
-  stub_available <- dt_stub_df_exists(data)
-  stub_df <- dt_stub_df_get(data)
-  groups_rows <- dt_groups_rows_get(data)
   summaries_present <- dt_summary_exists(data = data)
   list_of_summaries <- dt_summary_df_get(data = data)
   groups_rows_df <- dt_groups_rows_get(data = data)
-  stub_components <- dt_stub_components(data = data)
-
-  # Get the table width
-  table_width <- dt_options_get_value(data = data, option = "table_width")
 
   # Get table options
   row_group_border_top_color <- dt_options_get_value(data = data, option = "row_group_border_top_color")
@@ -1133,64 +1141,69 @@ create_body_component_rtf <- function(data) {
   table_body_vlines_color <- dt_options_get_value(data = data, option = "table_body_vlines_color")
   table_border_bottom_color <- dt_options_get_value(data, option = "table_border_bottom_color")
 
-  headings_vars <- boxh %>% dplyr::filter(type == "default") %>% dplyr::pull(var)
-  row_groups_present <- nrow(groups_rows) > 0
-  row_group_rows <- groups_rows$row_start
-  row_group_labels <- groups_rows$group_label
-  row_group_labels[is.na(row_group_labels)] <- ""
+  # Obtain all of the visible (`"default"`), non-stub
+  # column names for the table
+  default_vars <- dt_boxhead_get_vars_labels_default(data = data)
 
-  # Ensure that the columns are only the visible ones, and,
-  # that they are in order
-  body <- body %>% dplyr::select(dplyr::all_of(headings_vars))
+  # Get a matrix of all cell content for the body
+  cell_matrix <- get_body_component_cell_matrix(data = data)
 
-  n_cols <- ncol(body)
-  n_rows <- nrow(body)
+  # Get vector representation of stub layout
+  stub_layout <- get_stub_layout(data = data)
 
-  # Obtain alignments for each values in each visible column label
+  # Get the column alignments
   col_alignment <-
-    boxh %>%
-    dplyr::filter(type == "default") %>%
-    dplyr::pull(column_align)
+    c(
+      rep("right", length(stub_layout)),
+      dt_boxhead_get_vars_align_default(data = data)
+    )
 
-  if (stub_available) {
+  # Replace an NA group with an empty string
+  if (any(is.na(groups_rows_df$group_label))) {
 
-    stub_var <- dt_boxhead_get_var_stub(data = data)
-
-    body <-
-      dplyr::bind_cols(
-        dt_body_get(data) %>% dplyr::select(dplyr::one_of(stub_var)),
-        body
-      )
-
-    col_alignment <- c("left", col_alignment)
-    n_cols <- n_cols + 1
+    groups_rows_df <-
+      groups_rows_df %>%
+      dplyr::mutate(group_label = ifelse(is.na(group_label), "", group_label))
   }
 
-  # Obtain widths for each visible column label
+  row_groups_present <- nrow(groups_rows_df) > 0
+  row_group_rows <- groups_rows_df$row_start
+  row_group_labels <- groups_rows_df$group_label
+
+  n_cols <- ncol(cell_matrix)
+  n_rows <- nrow(cell_matrix)
+
+  # Obtain widths for each visible column label in units of twips
   col_widths <-
-    boxh %>%
+    dt_boxhead_get(data = data) %>%
     dplyr::filter(type %in% c("default", "stub")) %>%
     dplyr::arrange(dplyr::desc(type)) %>%
     dplyr::pull(column_width) %>%
-    unlist()
-
-  col_widths <-
+    unlist() %>%
     col_width_resolver_rtf(
-      table_width = table_width,
-      col_widths = col_widths,
-      n_cols = length(col_alignment)
+      table_width = dt_options_get_value(data = data, option = "table_width"),
+      col_widths = .,
+      n_cols = n_cols
     )
 
-  # Obtain all of the visible (`"default"`), non-stub
-  # column names for the table
-  default_vars <- dt_boxhead_get_vars_default(data = data)
-
   row_list_body <- list()
 
   for (i in seq_len(n_rows)) {
 
-    # Add group rows where necessary
-    if (row_groups_present && i %in% row_group_rows) {
+    group_info <- groups_rows_df[groups_rows_df$row_start == i, c("group_id", "group_label")]
+    if (nrow(group_info) == 0) {
+      group_info <- NULL
+    }
+    group_id <- group_info[["group_id"]]
+    group_label <- group_info[["group_label"]]
+
+    #
+    # Create a group heading row
+    #
+    if (
+      !is.null(group_id) &&
+      !("group_label" %in% stub_layout)
+    ) {
 
       row_list_body <-
         c(
@@ -1215,18 +1228,60 @@ create_body_component_rtf <- function(data) {
         )
     }
 
+    #
+    # Create a body row
+    #
     cell_list <-
       lapply(
-        seq_len(n_cols), FUN = function(x) {
+        seq_len(n_cols),
+        FUN = function(x) {
+
+          # If we are in row group column and the cell is blank (only the first
+          # value is shown) then we need to ensure that there is no top border
+          top_bottom_borders <-
+            c(
+              rtf_border("top", color = table_body_hlines_color, width = 10),
+              rtf_border("bottom", color = table_body_hlines_color, width = 10)
+            )
+          if ("group_label" %in% stub_layout && x == 1) {
+
+            if (i %in% groups_rows_df$row_start) {
+              top_bottom_borders[[2]] <- NULL
+            } else if (i %in% groups_rows_df$row_end) {
+              top_bottom_borders[[1]] <- NULL
+            } else {
+              top_bottom_borders <- NULL
+            }
+          }
+
+          # This performs a removal of top and bottom borders in the two-column
+          # stub case where summary rows follow
+          if (x == 1) {
+
+            row_limits <-
+              groups_rows_df %>%
+              dplyr::filter(row_end == i) %>%
+              dplyr::select(group_id)
+
+            if (nrow(row_limits) > 0) {
+
+              summary_rows_group_df <-
+                list_of_summaries[["summary_df_display_list"]][[row_limits$group_id]]
+
+              if (!is.null(summary_rows_group_df) && length(stub_layout) > 1) {
+                top_bottom_borders <- NULL
+              }
+            }
+          }
 
           rtf_tbl_cell(
             rtf_font(
               font_size = 10,
-              rtf_raw(body[[i, x]])
+              rtf_raw(cell_matrix[[i, x]])
             ),
             h_align = col_alignment[x],
             borders = list(
-              rtf_border("bottom", color = table_body_hlines_color, width = 10),
+              top_bottom_borders,
               rtf_border("left", color = table_body_vlines_color, width = 10),
               rtf_border("right", color = table_body_vlines_color, width = 10)
             )
@@ -1276,26 +1331,48 @@ create_body_component_rtf <- function(data) {
           list_of_summaries$summary_df_display_list[[group_id]] %>%
           dplyr::select(.env$rowname_col_private, .env$default_vars)
 
-        for (j in seq_len(nrow(summary_df))) {
+        n_summary_rows <- seq_len(nrow(summary_df))
+
+        for (j in n_summary_rows) {
+
+          summary_row <- as.matrix(summary_df)[j, ]
+
+          if (length(stub_layout) > 1) summary_row <- c("", summary_row)
 
           cell_list <-
             lapply(
               seq_len(n_cols), FUN = function(x) {
 
+                if (j == length(n_summary_rows) && "group_label" %in% stub_layout) {
+                  bottom_line_style <- "db"
+                  bottom_line_width <- 20
+                } else {
+                  bottom_line_style <- "s"
+                  bottom_line_width <- 10
+                }
+
+                bottom_border <-
+                  rtf_border(
+                    "bottom",
+                    style = bottom_line_style,
+                    color = table_body_hlines_color,
+                    width = bottom_line_width
+                  )
+
+                # Remove all (but the last) bottom borders for first column
+                # inside summary rows where there is a two-column stub
+                if (length(stub_layout) > 1 && x == 1 && j != length(n_summary_rows)) {
+                  bottom_border <- NULL
+                }
+
                 rtf_tbl_cell(
                   rtf_font(
                     font_size = 10,
-                    rtf_raw(summary_df[[j, x]])
+                    rtf_raw(summary_row[x])
                   ),
                   h_align = col_alignment[x],
                   borders = list(
-                    rtf_border(
-                      "top",
-                      style = ifelse(j == 1, "db", "s"),
-                      color = table_body_hlines_color,
-                      width = ifelse(j == 1, 20, 10)
-                    ),
-                    rtf_border("bottom", color = table_body_hlines_color, width = 10),
+                    bottom_border,
                     rtf_border("left", color = table_body_vlines_color, width = 10),
                     rtf_border("right", color = table_body_vlines_color, width = 10)
                   )
@@ -1330,6 +1407,16 @@ create_body_component_rtf <- function(data) {
 
     for (j in seq_len(nrow(grand_summary_df))) {
 
+      grand_summary_row <- as.matrix(grand_summary_df)[j, ]
+
+      merge_keys_cells <- rep(0, length(grand_summary_row))
+
+      if (length(stub_layout) > 1) {
+
+        grand_summary_row <- c(grand_summary_row[1], "", grand_summary_row[-1])
+        merge_keys_cells <- c(1, 2, rep(0, length(grand_summary_row) - 2))
+      }
+
       cell_list <-
         lapply(
           seq_len(n_cols), FUN = function(x) {
@@ -1337,9 +1424,10 @@ create_body_component_rtf <- function(data) {
             rtf_tbl_cell(
               rtf_font(
                 font_size = 10,
-                rtf_raw(grand_summary_df[[j, x]])
+                rtf_raw(grand_summary_row[x])
               ),
               h_align = col_alignment[x],
+              h_merge = merge_keys_cells[x],
               borders = list(
                 rtf_border(
                   "bottom",
@@ -1378,114 +1466,23 @@ create_body_component_rtf <- function(data) {
 }
 
 #
-# Table Footnotes
+# Table Footer Section
 #
-create_footnotes_component_rtf <- function(data) {
-
-  boxh <- dt_boxhead_get(data)
-
-  # Get table components and metadata using the `data`
-  footnotes_tbl <- dt_footnotes_get(data)
-
-  # If the `footnotes_tbl` object has no
-  # rows, then return an empty footnotes component
-  if (nrow(footnotes_tbl) == 0) {
-    row_list_footnotes <- list()
-    return(row_list_footnotes)
-  }
-
-  # Get table width
-  table_width <- dt_options_get_value(data = data, option = "table_width")
-
-  # Obtain widths for each visible column label
-  col_widths <-
-    boxh %>%
-    dplyr::filter(type %in% c("default", "stub")) %>%
-    dplyr::arrange(dplyr::desc(type)) %>%
-    dplyr::pull(column_width) %>%
-    unlist()
-
-  if (is.null(col_widths)) {
-
-    n_cols <-
-      boxh %>%
-      dplyr::filter(type %in% c("default", "stub")) %>%
-      nrow()
-
-    col_widths <- rep("100%", n_cols)
-  }
-
-  col_widths <-
-    col_width_resolver_rtf(
-      table_width = table_width,
-      col_widths = col_widths,
-      n_cols = length(col_widths)
-    )
-
-  table_width <- sum(col_widths)
-
-  footnotes_tbl <-
-    footnotes_tbl %>%
-    dplyr::select(fs_id, footnotes) %>%
-    dplyr::distinct()
-
-  n_footnotes <- nrow(footnotes_tbl)
-
-  footnote_text <- footnotes_tbl$footnotes
-  footnote_mark <- footnotes_tbl[["fs_id"]]
-
-  footnote_text <-
-    vapply(
-      footnote_text, FUN.VALUE = character(1), USE.NAMES = FALSE,
-      FUN = markdown_to_rtf
-    )
-
-  cell_list <- ""
-
-  for (i in seq_len(n_footnotes)) {
-
-    use_newline <- i != n_footnotes
-
-    cell_list <-
-      rtf_paste0(
-        cell_list,
-        rtf_font(
-          italic = TRUE,
-          super_sub = "super",
-          font_size = 10,
-          rtf_raw(footnote_mark[i])
-        ),
-        rtf_font(
-          font_size = 10,
-          rtf_raw(footnote_text[i], " ")
-        )
-      )
-  }
-
-  # Return a list of RTF table rows (a single row) for the footnotes section
-  rtf_tbl_row(
-    list(rtf_tbl_cell(cell_list)),
-    widths = table_width,
-    height = 0
-  )
-}
-
-#
-# Table Source Notes
-#
-create_source_notes_component_rtf <- function(data) {
-
-  boxh <- dt_boxhead_get(data)
+create_footer_component_rtf <- function(data) {
 
   # Get table components and metadata using the `data`
   source_notes <- dt_source_notes_get(data)
 
-  # If there are no source notes then return an empty list
-  if (length(source_notes) == 0) {
-    row_list_source_notes <- list()
-    return(row_list_source_notes)
+  footnotes_tbl <- dt_footnotes_get(data = data)
+  source_notes_vec <- dt_source_notes_get(data = data)
+
+  # If there are no footnotes or source notes, return an empty list
+  if (nrow(footnotes_tbl) == 0 && length(source_notes_vec) == 0) {
+    return(list())
   }
 
+  boxh <- dt_boxhead_get(data)
+
   # Get table width
   table_width <- dt_options_get_value(data = data, option = "table_width")
 
@@ -1516,27 +1513,123 @@ create_source_notes_component_rtf <- function(data) {
 
   table_width <- sum(col_widths)
 
-  n_source_notes <- length(source_notes)
-  row_list_source_notes <- list()
-
   cell_list <- ""
 
-  for (i in seq_len(n_source_notes)) {
+  # Get the multiline and separator options for footnotes and source notes
+  footnotes_multiline <- dt_options_get_value(data = data, option = "footnotes_multiline")
+  footnotes_sep <- dt_options_get_value(data = data, option = "footnotes_sep")
+  source_notes_multiline <- dt_options_get_value(data = data, option = "source_notes_multiline")
+  source_notes_sep <- dt_options_get_value(data = data, option = "source_notes_sep")
 
-    cell_list <-
-      rtf_paste0(
-        cell_list,
-        rtf_font(
-          font_size = 10,
-          rtf_raw(source_notes[i])
-        )
+  # Create a formatted footnotes string
+  if (nrow(footnotes_tbl) > 0) {
+
+    footnotes_tbl <-
+      footnotes_tbl %>%
+      dplyr::select(fs_id, footnotes) %>%
+      dplyr::distinct()
+
+    footnote_text <- footnotes_tbl[["footnotes"]]
+    footnote_mark <- footnotes_tbl[["fs_id"]]
+
+    footnote_text <-
+      vapply(
+        footnote_text, FUN.VALUE = character(1), USE.NAMES = FALSE,
+        FUN = process_text, context = "rtf"
       )
+
+    footnotes <- c()
+
+    for (i in seq_along(footnote_mark)) {
+
+      footnotes <-
+        c(
+          footnotes,
+          rtf_paste0(
+            cell_list,
+            rtf_font(
+              italic = TRUE,
+              super_sub = "super",
+              font_size = 10,
+              rtf_raw(footnote_mark[i])
+            ),
+            rtf_font(
+              font_size = 10,
+              rtf_raw(footnote_text[i])
+            )
+          )
+        )
+    }
+
+    if (footnotes_multiline) {
+      footnotes <- paste(footnotes, collapse = rtf_raw("\\line"))
+    } else {
+      footnotes <- paste(footnotes, collapse = footnotes_sep)
+    }
+  } else {
+    footnotes <- ""
   }
 
-  # Return a list of RTF table rows (a single row) for the source notes section
-  rtf_tbl_row(
-    list(rtf_tbl_cell(cell_list)),
-    widths = table_width,
-    height = 0
+  # Create a formatted source notes string
+  if (length(source_notes_vec) > 0) {
+
+    source_notes <- c()
+
+    for (i in seq_along(source_notes_vec)) {
+
+      source_notes <-
+        c(
+          source_notes,
+          rtf_paste0(
+            cell_list,
+            rtf_font(
+              font_size = 10,
+              rtf_raw(source_notes_vec[i])
+            )
+          )
+        )
+    }
+
+    if (source_notes_multiline) {
+      source_notes <- paste(source_notes, collapse = "\\line")
+    } else {
+      source_notes <- paste(source_notes, collapse = source_notes_sep)
+    }
+  } else {
+    source_notes <- ""
+  }
+
+  # Return a list of RTF table rows (up to two rows) for the footer
+  list(
+    if (footnotes != "") {
+      rtf_tbl_row(
+        rtf_tbl_cell(
+          rtf_paste0(
+            cell_list,
+            rtf_font(
+              font_size = 10,
+              rtf_raw(footnotes)
+            )
+          )
+        ),
+        widths = table_width,
+        height = 0
+      )
+    },
+    if (source_notes != "") {
+      rtf_tbl_row(
+        rtf_tbl_cell(
+          rtf_paste0(
+            cell_list,
+            rtf_font(
+              font_size = 10,
+              rtf_raw(source_notes)
+            )
+          )
+        ),
+        widths = table_width,
+        height = 0
+      )
+    }
   )
 }
