@@ -30,6 +30,7 @@ globalVariables(
     "arrange_dfs",
     "b",
     "blue",
+    "built",
     "boxhead",
     "category",
     "colname",
@@ -38,7 +39,9 @@ globalVariables(
     "colnum_final",
     "column_align",
     "column_label",
+    "column_width",
     "colors",
+    "conv",
     "copyright",
     "curr_code",
     "curr_name",
@@ -53,10 +56,13 @@ globalVariables(
     "get_groups_rows",
     "g",
     "green",
+    "group_id",
     "group_label",
+    "groups",
     "grpname",
     "grprow",
     "integrate_summary_lines",
+    "label",
     "locname",
     "locnum",
     "missing_text",
@@ -69,6 +75,7 @@ globalVariables(
     "palette",
     "red",
     "row_end",
+    "row_start",
     "rownum",
     "rownum_i",
     "styles",
@@ -93,6 +100,7 @@ globalVariables(
     "text_col",
     "time",
     "type",
+    "unit",
     "value",
     "var",
     "weight",
@@ -111,11 +119,14 @@ globalVariables(
 #'   \item `gt.row_group.sep`: a separator between groups for the row group
 #'   label.
 #' }
+#'
+#' @keywords internal
 #' @name gt-options
 NULL
 
 gt_default_options <- list(
   gt.row_group.sep = " - ",
+  gt.rtf_page_width = 9468L,
   gt.html_tag_check = TRUE
 )
 
