@@ -101,7 +101,7 @@ expect_tab <- function(tab,
 
   dt_options_get(data = tab) %>%
     dim() %>%
-    expect_equal(c(137, 5))
+    expect_equal(c(156, 5))
 
   dt_transforms_get(data = tab) %>%
     length() %>%
@@ -145,7 +145,7 @@ gt_attr_names <- function() {
     "_stub_df", "_row_groups",
     "_heading", "_spanners", "_stubhead",
     "_footnotes", "_source_notes", "_formats", "_styles",
-    "_summary", "_options", "_transforms", "_has_built"
+    "_summary", "_options", "_transforms", "_locale", "_has_built"
   )
 }
 
