@@ -17,7 +17,7 @@ test_that("the `cols_move()` function works correctly", {
   # Create a `tbl_html` object with `gt()`; the `mpg`,
   # `cyl`, and `drat` columns placed after `drat`
   tbl_html <-
-    gt(data = mtcars_short) %>%
+    gt(mtcars_short) %>%
     cols_move(columns = c(mpg, cyl, disp), after = drat)
 
   # Expect a particular ordering of columns in `_boxh`
@@ -41,7 +41,7 @@ test_that("the `cols_move()` function works correctly", {
   # Create a `tbl_html` object with `gt()`; the `mpg`,
   # `cyl`, and `drat` columns placed after `drat` using vectors
   tbl_html <-
-    gt(data = mtcars_short) %>%
+    gt(mtcars_short) %>%
     cols_move(columns = c("mpg", "cyl", "disp"), after = c("drat"))
 
   # Expect a particular ordering of columns in `_boxh`
@@ -65,7 +65,7 @@ test_that("the `cols_move()` function works correctly", {
   # Create a `tbl_html` object with `gt()`; the `mpg`,
   # `cyl`, and `drat` columns placed after `carb` (the end of the series)
   tbl_html <-
-    gt(data = mtcars_short) %>%
+    gt(mtcars_short) %>%
     cols_move(columns = c(mpg, cyl, disp), after = carb)
 
   # Expect a particular ordering of columns in the internal `boxh_df`
@@ -88,17 +88,17 @@ test_that("the `cols_move()` function works correctly", {
 
   # Expect an error if more than one column provided in `after`
   expect_error(
-    gt(data = mtcars_short) %>%
+    gt(mtcars_short) %>%
       cols_move(columns = c(mpg, cyl, disp), after = c(am, wt)))
 
   # Expect an error if the column provided in `after` doesn't exist
   expect_error(
-    gt(data = mtcars_short) %>%
+    gt(mtcars_short) %>%
       cols_move(columns = c(mpg, cyl, disp), after = wts))
 
   # Expect an error if any of the `columns` doesn't exist in `data_df`
   expect_error(
-    gt(data = mtcars_short) %>%
+    gt(mtcars_short) %>%
       cols_move(columns = c(mpg, cyls, disp), after = wt))
 })
 
@@ -110,7 +110,7 @@ test_that("the `cols_move_to_start()` function works correctly", {
   # Create a `tbl_html` object with `gt()`; the `gear`,
   # and `carb` columns placed at the start
   tbl_html <-
-    gt(data = mtcars_short) %>%
+    gt(mtcars_short) %>%
     cols_move_to_start(columns = c(gear, carb))
 
   # Expect a particular ordering of columns in the internal `boxh_df`
@@ -134,7 +134,7 @@ test_that("the `cols_move_to_start()` function works correctly", {
   # Create a `tbl_html` object with `gt()`; the `gear`,
   # and `carb` columns placed at the start using vectors
   tbl_html <-
-    gt(data = mtcars_short) %>%
+    gt(mtcars_short) %>%
     cols_move_to_start(columns = c("gear", "carb"))
 
   # Expect a particular ordering of columns in the internal `boxh_df`
@@ -157,7 +157,7 @@ test_that("the `cols_move_to_start()` function works correctly", {
 
   # Expect an error if any of the `columns` doesn't exist in `data_df`
   expect_error(
-    gt(data = mtcars_short) %>%
+    gt(mtcars_short) %>%
       cols_move_to_start(columns = c(mpg, cyls, disp)))
 })
 
@@ -169,7 +169,7 @@ test_that("the `cols_move_to_end()` function works correctly", {
   # Create a `tbl_html` object with `gt()`; the `gear`,
   # and `carb` columns placed at the end
   tbl_html <-
-    gt(data = mtcars_short) %>%
+    gt(mtcars_short) %>%
     cols_move_to_end(columns = c(gear, carb))
 
   # Expect a particular ordering of columns in the internal `boxh_df`
@@ -193,7 +193,7 @@ test_that("the `cols_move_to_end()` function works correctly", {
   # Create a `tbl_html` object with `gt()`; the `gear`,
   # and `carb` columns placed at the start using vectors
   tbl_html <-
-    gt(data = mtcars_short) %>%
+    gt(mtcars_short) %>%
     cols_move_to_end(columns = c("gear", "carb"))
 
   # Expect a particular ordering of columns in the internal `boxh_df`
@@ -216,6 +216,6 @@ test_that("the `cols_move_to_end()` function works correctly", {
 
   # Expect an error if any of the `columns` doesn't exist in `data_df`
   expect_error(
-    gt(data = mtcars_short) %>%
+    gt(mtcars_short) %>%
       cols_move_to_end(columns = c(mpg, cyls, disp)))
 })
