@@ -88,8 +88,8 @@ test_that("the `fmt_percent()` function works with conditional `rows`", {
          decimals = 2,
          rows = num_1 < 1000) %>%
        render_formats_test(context = "html"))[["num_1"]],
-    c("1836.23", "2763.39", "93,729.00&percnt;", "64,300.00&percnt;",
-      "21,223.20&percnt;", "0.00&percnt;", "&minus;2,324.00&percnt;")
+    c("1836.23", "2763.39", "93,729.00%", "64,300.00%",
+      "21,223.20%", "0.00%", "&minus;2,324.00%")
   )
 
   expect_equal(
@@ -99,7 +99,7 @@ test_that("the `fmt_percent()` function works with conditional `rows`", {
          decimals = 2,
          rows = char_2 %in% c("june", "july") & grepl("sa.*", char_1)) %>%
        render_formats_test(context = "html"))[["num_2"]],
-    c("3,400.00&percnt;", "74", "23", "NA", "35", "NA", "NA")
+    c("3,400.00%", "74", "23", "NA", "35", "NA", "NA")
   )
 })
 
